@@ -202,8 +202,8 @@ panel_run_dialog_set_icon (PanelRunDialog *dialog,
 		gtk_window_set_icon_name (GTK_WINDOW (dialog->run_dialog),
 					  PANEL_RUN_ICON);
 		
-		/* FIXME: waiting for bug #116577
-		gtk_drag_source_set_icon_name (dialog->run_dialog, PANEL_RUN_ICON); */
+		gtk_drag_source_set_icon_name (dialog->run_dialog,
+					       PANEL_RUN_ICON);
 	}
 }
 
@@ -499,6 +499,8 @@ fuzzy_command_match (const char *cmd1,
 	char **tokens;
 	char  *word1, *word2;
 
+	g_return_val_if_fail (cmd1 && cmd2, TRUE);
+
 	*fuzzy = FALSE;
 
 	if (!strcmp (cmd1, cmd2))
@@ -793,15 +795,17 @@ panel_run_dialog_add_items_idle (PanelRunDialog *dialog)
 	prev_name = NULL;
 	for (l = all_applications; l; l = next) {
 		GMenuTreeEntry *entry = l->data;
+		const char     *entry_name;
 
 		next = l->next;
 
-		if (prev_name && strcmp (gmenu_tree_entry_get_name (entry), prev_name) == 0) {
+		entry_name = gmenu_tree_entry_get_name (entry);
+		if (prev_name && entry_name && strcmp (entry_name, prev_name) == 0) {
 			gmenu_tree_item_unref (entry);
 
 			all_applications = g_slist_delete_link (all_applications, l);
 		} else {
-			prev_name = gmenu_tree_entry_get_name (entry);
+			prev_name = entry_name;
 		}
 	}
 
@@ -830,6 +834,8 @@ panel_run_dialog_add_items_idle (PanelRunDialog *dialog)
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->program_list), 
 				 GTK_TREE_MODEL (dialog->program_list_store));
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (dialog->program_list),
+					 COLUMN_NAME);
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	column = gtk_tree_view_column_new ();
@@ -1423,6 +1429,7 @@ entry_event (GtkEditable    *entry,
 			
 			dialog->completion_started = TRUE;
 
+			g_free (temp);
 			g_free (nprefix);
 			g_free (prefix);
 			
